# -*- coding: utf-8 -*-

###########################################################################
## Python code generated with wxFormBuilder (version Oct 26 2018)
## http://www.wxformbuilder.org/
##
## PLEASE DO *NOT* EDIT THIS FILE!
###########################################################################
import os

import wx
import wx.xrc
import wx.dataview

from  Config.Init import *
import Res.Allicons as icon

import Database.PostGet as PG
import Database.PostGet2 as PG2
import Database.MenuSet2 as MS

import importlib
#import importlib.util

from AI.Analiz import *
import AI.OpnSrc as OS

_ = wx.GetTranslation

###########################################################################
## Class MyPanel9
###########################################################################

class MyPanel1 ( wx.Panel ):

	def __init__( self, parent, id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.Size( 555,480 ), style = wx.TAB_TRAVERSAL, name = wx.EmptyString ):
		wx.Panel.__init__ ( self, parent, id = id, pos = pos, size = size, style = style, name = name )

		Vsz1 = wx.BoxSizer( wx.VERTICAL )

		self.getMData = MS.GetData(u'Menu2.db', u'')
		self.setMDate = MS.SetData(u'', u'', u'')

		self.Splt1 = wx.SplitterWindow( self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.SP_3D|wx.SP_LIVE_UPDATE|wx.SP_NO_XP_THEME|wx.SP_THIN_SASH )
		self.Splt1.Bind( wx.EVT_IDLE, self.Splt1OnIdle )

		self.P1 = wx.Panel( self.Splt1, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.TAB_TRAVERSAL )
		Vsz2 = wx.BoxSizer( wx.VERTICAL )

		self.Titr1 = wx.StaticText( self.P1, wx.ID_ANY, _(u"Type of Machin Learning"), wx.DefaultPosition, wx.DefaultSize, 0 )
		self.Titr1.Wrap( -1 )

		Vsz2.Add( self.Titr1, 0, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL, 5 )

		Hsz1 = wx.BoxSizer(wx.HORIZONTAL)

		#chis1Choices = [ u"Supervised Learning (11)",u"Semi-Supervised Learning (15)",u"Unsupervised Learning (21)",u"Reinforcement Learning (31)" ]
		chis1Choices = [l for l in OpenListML()[0].values()]
		chis1Choices.append("All MLA source file in HDD ")
		self.chis1 = wx.Choice( self.P1, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, chis1Choices, 0 )
		self.chis1.SetSelection( 0 )
		#Vsz2.Add( self.chis1, 0, wx.ALL|wx.EXPAND, 5 )

		Hsz1.Add(self.chis1, 1, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		self.MLset = wx.BitmapButton(self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize,
		                             wx.BU_AUTODRAW | 0)

		self.MLset.SetBitmap(wx.ArtProvider.GetBitmap(wx.ART_INFORMATION, wx.ART_BUTTON))
		Hsz1.Add(self.MLset, 0, wx.ALL, 5)

		# Hsz1 = wx.BoxSizer( wx.HORIZONTAL )
		#
		# self.lbl1 = wx.StaticText( self.P1, wx.ID_ANY, u"Problem Type", wx.DefaultPosition, wx.DefaultSize, 0 )
		# self.lbl1.Wrap( -1 )
		#
		# Hsz1.Add( self.lbl1, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )
		#
		# chis2Choices = [ u"Regression Problem", u"Classification Problem" ]
		# self.chis2 = wx.Choice( self.P1, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, chis2Choices, 0 )
		# self.chis2.SetSelection( 0 )
		# Hsz1.Add( self.chis2, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )
		#
		#
		Vsz2.Add( Hsz1, 0, wx.EXPAND, 5 )

		self.TLC1 = wx.dataview.TreeListCtrl(self.P1, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.dataview.TL_DEFAULT_STYLE)
		self.TLC1.AppendColumn(_(u"Learn Type"), 205, wx.ALIGN_LEFT, wx.COL_RESIZABLE)
		self.TLC1.AppendColumn(_(u"Method"), 45, wx.ALIGN_LEFT, wx.COL_RESIZABLE)

		Vsz2.Add(self.TLC1, 1, wx.EXPAND | wx.ALL, 5)

		self.filllist()

		Hsz2 = wx.BoxSizer( wx.HORIZONTAL )

		self.SlcDta = wx.Button(self.P1, wx.ID_ANY, _(u"Select Data"), wx.DefaultPosition, wx.DefaultSize, 0)
		Hsz2.Add(self.SlcDta, 1, wx.ALL, 5)

		self.ConDta = wx.Button(self.P1, wx.ID_ANY, _(u"Connect Data"), wx.DefaultPosition, wx.DefaultSize, 0)
		Hsz2.Add(self.ConDta, 1, wx.ALL, 5)

		Vsz2.Add( Hsz2, 0, wx.EXPAND, 5 )

		Hsz3 = wx.BoxSizer( wx.HORIZONTAL )

		self.btn1 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )
		#self.btn1.SetBitmap(wx.Bitmap(ICON16_PATH + u'add.png', wx.BITMAP_TYPE_ANY))
		self.btn1.SetBitmap(icon.add.GetBitmap())
		self.btn1.SetToolTip(_(u"Add"))
		Hsz3.Add( self.btn1, 0, wx.ALL, 5 )

		self.btn2 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )
		#self.btn2.SetBitmap(wx.Bitmap(ICON16_PATH + u'edit_button.png', wx.BITMAP_TYPE_ANY))
		self.btn2.SetBitmap(icon.edit_button.GetBitmap())
		self.btn2.SetToolTip(_(u"Edit"))
		Hsz3.Add( self.btn2, 0, wx.ALL, 5 )

		self.btn3 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )
		#self.btn3.SetBitmap(wx.Bitmap(ICON16_PATH + u'delete.png', wx.BITMAP_TYPE_ANY))
		self.btn3.SetBitmap(icon.delete.GetBitmap())
		self.btn3.SetToolTip(_(u"Delete"))
		Hsz3.Add( self.btn3, 0, wx.ALL, 5 )

		self.btn4 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )
		#self.btn4.SetBitmap(wx.Bitmap(ICON16_PATH + u'brain_trainer.png', wx.BITMAP_TYPE_ANY))
		self.btn4.SetBitmap(icon.brain_trainer.GetBitmap())
		self.btn4.SetToolTip(_(u"Preview"))
		Hsz3.Add( self.btn4, 0, wx.ALL, 5 )

		self.btn5 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )
		#self.btn5.SetBitmap(wx.Bitmap(ICON16_PATH + u'update.png', wx.BITMAP_TYPE_ANY))
		self.btn5.SetBitmap(icon.update.GetBitmap())
		self.btn5.SetToolTip(_(u"Update"))
		Hsz3.Add( self.btn5, 0, wx.ALL, 5 )

		self.btn6 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )
		#self.btn6.SetBitmap(wx.Bitmap(ICON16_PATH + u'accept_button.png', wx.BITMAP_TYPE_ANY))
		self.btn6.SetBitmap(icon.accept_button.GetBitmap())
		self.btn6.SetToolTip(_(u"Apply"))
		Hsz3.Add( self.btn6, 0, wx.ALL, 5 )

		self.btn7 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )
		#self.btn7.SetBitmap(wx.Bitmap(ICON16_PATH + u'lightning.png', wx.BITMAP_TYPE_ANY))
		self.btn7.SetBitmap(icon.lightning.GetBitmap())
		self.btn7.SetToolTip(_(u"Generate"))
		Hsz3.Add( self.btn7, 0, wx.ALL, 5 )


		Vsz2.Add( Hsz3, 0, wx.EXPAND, 5 )


		self.P1.SetSizer( Vsz2 )
		self.P1.Layout()
		Vsz2.Fit( self.P1 )
		self.P2 = wx.Panel( self.Splt1, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.TAB_TRAVERSAL )
		Vsz3 = wx.BoxSizer( wx.VERTICAL )

		Hsz15 = wx.BoxSizer( wx.HORIZONTAL )

		self.lblA = wx.StaticText( self.P2, wx.ID_ANY, _(u"Algorithm Pane Parameter "), wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lblA.Wrap( -1 )

		Hsz15.Add( self.lblA, 1, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.Adbtn = wx.BitmapButton( self.P2, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )
		#self.Adbtn.SetBitmap(wx.Bitmap(ICON16_PATH + u'add.png', wx.BITMAP_TYPE_ANY))
		self.Adbtn.SetBitmap(icon.add.GetBitmap())
		Hsz15.Add( self.Adbtn, 0, wx.ALL, 5 )

		self.Edbtn = wx.BitmapButton( self.P2, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )
		#self.Edbtn.SetBitmap(wx.Bitmap(ICON16_PATH + u'edit_button.png', wx.BITMAP_TYPE_ANY))
		self.Edbtn.SetBitmap(icon.edit_button.GetBitmap())
		Hsz15.Add( self.Edbtn, 0, wx.ALL, 5 )

		self.Dlbtn = wx.BitmapButton( self.P2, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )
		#self.Dlbtn.SetBitmap(wx.Bitmap(ICON16_PATH + u'delete.png', wx.BITMAP_TYPE_ANY))
		self.Dlbtn.SetBitmap(icon.delete.GetBitmap())
		Hsz15.Add( self.Dlbtn, 0, wx.ALL, 5 )


		Vsz3.Add( Hsz15, 0, wx.EXPAND, 5 )

		self.Lin1 = wx.StaticLine( self.P2, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.LI_HORIZONTAL )
		Vsz3.Add( self.Lin1, 0, wx.EXPAND |wx.ALL, 5 )

		self.lstpane = self.getMData.MLPansFils(u' Join MLinfo on MLPane.MLPid = MLinfo.MLPid')
		Src_dir = self.getMData.GetImpCod('4444')[0][0]

		self.ChsBok = wx.Choicebook( self.P2, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.CHB_DEFAULT )
		self.PLP19 = []
		j = 0

		for lp in self.lstpane:
			#print(lp)
			#i = importlib.import_module(u'GUI.MLPane.' + lp[1])
			i = importlib.import_module(Src_dir+'.' + lp[1])
			self.PLP19.append(i.P19(self.ChsBok))
			if j == 0:
				fp = True
			else:
				fp = False
			self.ChsBok.AddPage(self.PLP19[j], lp[3], fp)
			j += 1

		Vsz3.Add( self.ChsBok, 1, wx.EXPAND |wx.ALL, 5 )


		self.P2.SetSizer( Vsz3 )
		self.P2.Layout()
		Vsz3.Fit( self.P2 )
		self.Splt1.SplitVertically( self.P1, self.P2, 255 )
		Vsz1.Add( self.Splt1, 1, wx.EXPAND, 5 )


		self.SetSizer( Vsz1 )
		self.Layout()

		# Connect Events
		self.chis1.Bind( wx.EVT_CHOICE, self.typml )
		#self.chis2.Bind( wx.EVT_CHOICE, self.typpl )
		self.MLset.Bind(wx.EVT_BUTTON, self.MLsting)
		self.TLC1.Bind( wx.dataview.EVT_TREELIST_SELECTION_CHANGED, self.slctit )
		self.SlcDta.Bind(wx.EVT_BUTTON, self.selctdata)
		self.ConDta.Bind(wx.EVT_BUTTON, self.conctdata)
		#self.SrcShw.Bind( wx.EVT_BUTTON, self.srcml )
		self.btn1.Bind( wx.EVT_BUTTON, self.addit )
		self.btn2.Bind( wx.EVT_BUTTON, self.editit )
		self.btn3.Bind( wx.EVT_BUTTON, self.delit )
		self.btn4.Bind( wx.EVT_BUTTON, self.prw )
		self.btn5.Bind( wx.EVT_BUTTON, self.upd )
		self.btn6.Bind( wx.EVT_BUTTON, self.aply )
		self.btn7.Bind( wx.EVT_BUTTON, self.gnrt )
		self.Adbtn.Bind( wx.EVT_BUTTON, self.addAl )
		self.Edbtn.Bind( wx.EVT_BUTTON, self.edtAl )
		self.Dlbtn.Bind( wx.EVT_BUTTON, self.delAl )
		self.ChsBok.Bind( wx.EVT_CHOICEBOOK_PAGE_CHANGED, self.chgedpg )
		self.ChsBok.Bind( wx.EVT_CHOICEBOOK_PAGE_CHANGING, self.chgngpg )

	def __del__( self ):
		pass


	# Virtual event handlers, overide them in your derived class
	def filllist(self):
		ch1 = self.chis1.GetStringSelection()
		coding,algcod = OpenListML()
		#support-vector machines, linear regression, logistic regression, neural networks, and nearest neighbor methods,
		#print(ch1,coding,algcod)
		if ch1 in coding.values():
			for mcod in coding:
				if ch1 == coding[mcod]:
					#print(mcod)
					self.codings = mcod
					myfrng = mcod[0]
					mylrng = mcod[1]
		else:
			self.codings = ()
			myfrng = 10000
			mylrng = 10001
		mylst = []
		if self.codings != () and myfrng != 10000 and mylrng != 10001 :
			for cod in algcod:
				if cod[0] > myfrng and cod[1] < mylrng:
					fcod = cod[0]
					tcod = cod[1]
					mylst = self.getMData.AllML(u' where MLinfo.MLPid < %d and MLinfo.MLPid >= %d' %(tcod,fcod))
					if mylst != []:
						Mroot = self.TLC1.GetRootItem()
						self.rootm = self.TLC1.AppendItem(Mroot, algcod[cod])
						for mtd in mylst:
							self.mlmtd = self.TLC1.AppendItem(self.rootm, u'Some Method')
							self.TLC1.SetItemText(self.mlmtd, 0, str(mtd[0])+' '+mtd[1])
							self.TLC1.SetItemText(self.mlmtd, 1, mtd[2])

		else:
			lstmla , lstmlp = self.findMLfile()
			Mroot = self.TLC1.GetRootItem()
			lstalgo = [ A[1] for A in self.getMData.MLAlgoFils()]
			lstpans = [P[1] for P in self.lstpane]
			for mla in lstmla :
				if mla.replace('.py','') not in lstalgo and mla[0] != '_' and '.py' in mla:
					self.mlafil = self.TLC1.AppendItem(Mroot, u'MLA files')
					self.TLC1.SetItemText(self.mlafil, 0, mla)
					self.TLC1.SetItemText(self.mlafil, 1, '????')
			for mlp in lstmlp:
				if mlp.replace('.py','') not in lstpans and mlp[0] != '_' and '.py' in mlp:
					self.mlpfil = self.TLC1.AppendItem(Mroot, u'MLP files')
					self.TLC1.SetItemText(self.mlpfil, 0, mlp)
					self.TLC1.SetItemText(self.mlpfil, 1, '****')

				#self.findMLfile()
	def findMLfile(self):
		listMLP = os.listdir(Src_mlp)
		listMLA = os.listdir(Src_mla)
		return listMLA, listMLP

	def MLsting(self, event):
		itxt = fil2txt(CONFIG_PATH+"MLmethod.ini")
		dlg = wx.Dialog(self, -1, "Setting of MLA Coding")
		pnl = MyPanel3(dlg, CONFIG_PATH+"MLmethod.ini", itxt)
		dlg.SetSize((380,380))
		dlg.ShowModal()
		dlg.Destroy()

	def typml( self, event ):
		self.TLC1.DeleteAllItems()
		self.filllist()
		self.TLC1.Refresh()

	#def typpl( self, event ):
	#	event.Skip()

	def slctit( self, event ):
		event.Skip()

	def selctdata(self, event):
		if len(self.PLP19) > 0:
			chos = self.ChsBok.GetChoiceCtrl()
			pnl = self.PLP19[chos.GetSelection()]
			pnl.Start()
		else:
			wx.MessageBox(_("Please Create a Machine Learning Panel and write your code in Start function "))

	def conctdata(self, event):
		wx.MessageBox(_("We will soon create this part for connect between data here"))

	#def srcml( self, event ):
		#event.Skip()

	def addit( self, event ):
		newfile = GUI_PATH + 'Temp\\untitle.py'
		self.Frm = wx.Frame(self, style=wx.CAPTION | wx.CLOSE_BOX | wx.FRAME_FLOAT_ON_PARENT | wx.TAB_TRAVERSAL)
		self.Pnl = OS.SrcPanel(self.Frm, newfile)
		self.Frm.SetMenuBar(OS.MyMenuBar1(u'MLA'))
		self.Frm.SetSize((700, 500))
		self.Frm.SetLabel(u'untitle.py')
		self.Frm.Show()
		event.Skip()

	def editit( self, event ):
		myslct = self.TLC1.GetSelection()
		myalg = self.TLC1.GetItemText(myslct, 1)
		if myalg != '????' and myalg != '****':
			thsfile = Src_mla+self.getMData.MLPansgetAl(myalg)[0][1]+'.py'
		else:
			if myalg == '????':
				thsfile = Src_mla+self.TLC1.GetItemText(myslct, 0)
			if myalg == '****':
				thsfile = Src_mlp+self.TLC1.GetItemText(myslct, 0)

		self.Frm = wx.Frame(self, style=wx.CAPTION | wx.CLOSE_BOX | wx.FRAME_FLOAT_ON_PARENT | wx.TAB_TRAVERSAL)
		self.Pnl = OS.SrcPanel(self.Frm,  thsfile )
		self.Frm.SetMenuBar(OS.MyMenuBar1(u'MLA'))
		self.Frm.SetSize((700, 500))
		self.Frm.SetLabel( thsfile )
		self.Frm.Show()
		event.Skip()

	def delit( self, event ):
		myslct = self.TLC1.GetSelection()
		thsmtd = self.TLC1.GetItemText(myslct, 0)
		mymthd = self.TLC1.GetItemText(myslct, 1)
		if mymthd == '????' or mymthd == '****':

			if mymthd == '????':
				thsfile = Src_mla+self.TLC1.GetItemText(myslct, 0)
			if mymthd == '****':
				thsfile = Src_mlp+self.TLC1.GetItemText(myslct, 0)
			answer = wx.MessageBox(_("Do you like delete program [%s] from HDD" % thsfile), style=wx.YES_NO)
			if answer == 2:
				hndlid = 0
				#print(self.thsfile)
				if os.path.isfile(thsfile):
					os.remove(thsfile)
					wx.MessageBox(_("File Successfully Remove from HardDisk"))
				else:
					wx.MessageBox(_("File Open or dose not exist please close it or check Harddisk"))
		else:
			answer = wx.MessageBox(_("If you Delete Algorithm maybe some Panel Not work correctly! Do you like delete Algorithm [%s] from list" % thsmtd), style=wx.YES_NO)
			if answer == 2:
				self.setMDate.Table = u'MLAlgo'
				self.setMDate.Delitem(" MLAlgo.MLcod = '%s' " % mymthd)
				self.setMDate.Table = u'MLinfo'
				self.setMDate.Delitem(" MLinfo.MLcod = '%s' " % mymthd)
				wx.MessageBox(_("Algorithm successful delete from list "))
		self.upd(event)


	def prw( self, event ):
		if len(self.PLP19) > 0:
			chos = self.ChsBok.GetChoiceCtrl()
			pnl = self.PLP19[chos.GetSelection()]
			pnl.Test()
		else:
			wx.MessageBox(_("Please Create a Machine Learning Panel and write your code in Test function "))

		event.Skip()

	def upd( self, event ):
		self.ChsBok.DeleteAllPages()
		self.PLP19 = []
		j = 0
		self.lstpane = self.getMData.MLPansFils(u' Join MLinfo on MLPane.MLPid = MLinfo.MLPid ')
		Src_dir = self.getMData.GetImpCod('4444')[0][0]
		for lp in self.lstpane:
			#print(lp)
			#i = importlib.import_module(u'GUI.MLPane.' + lp[1])
			i = importlib.import_module(Src_dir+'.' + lp[1])
			self.PLP19.append(i.P19(self.ChsBok))
			if j == 0:
				fp = True
			else:
				fp = False
			self.ChsBok.AddPage(self.PLP19[j], lp[3], fp)
			j += 1

		self.TLC1.DeleteAllItems()
		self.filllist()
		self.TLC1.Refresh()
		event.Skip()

	def aply( self, event ):
		myslct = self.TLC1.GetSelection()
		myalg = self.TLC1.GetItemText(myslct, 1)
		if myalg != '????' and myalg != '****':
			wx.MessageBox(_(u'Algorithm already added '))
		else:
			if myalg == '????':
				ifil = self.TLC1.GetItemText(myslct, 0).replace('.py','')
				#print(ifil)
				lebls = [u'Algorithm Name', u'Algorithm Code', u'Algorithm file']
				data = [ifil]
				algid, algnm, algcd = self.opengeneratewin(lebls,data)
				#print(algid, algnm, algcd)
				if algnm != u'' and algcd != u'' and algid != u'':
					if int(algid) > 11000 and int(algid) < 60999:
						self.setMDate.Table = u'MLinfo'
						self.setMDate.Additem(u' MLPid, MLname, MLcod', [int(algid), algnm, algcd])
						self.setMDate.Table = u'MLAlgo'
						self.setMDate.Additem(u' MLcod, MLAsrc', [algcd, ifil])
						wx.MessageBox(_(u'Your source Add to list Successfully.'))
					else:
						wx.MessageBox(_(u'Please attend to coding range!'))
				else:
					wx.MessageBox(_(u'Some fields is empty or wrong ! try again!'))
			if myalg == '****':
				wx.MessageBox(_(u'Please Use <Generate> for create Panel'))
		self.upd(event)
		#event.Skip()

	def gnrt( self, event ):
		myslct = self.TLC1.GetSelection()
		myalg = self.TLC1.GetItemText(myslct, 1)
		if myalg != '????' and myalg != '****':
			wx.MessageBox(_(u'Algorithm already added '))
		else:

			if myalg == '****':
				af = Anlzfil(Src_mlp+self.TLC1.GetItemText(myslct, 0))
				ifil = self.TLC1.GetItemText(myslct, 0).replace('.py','')
				#print(ifil,af)
				imlaim = af.hasMLAimpis()
				if len(imlaim[0])>0 :
					algmthd = imlaim[0][0].split(' ')[1].replace('Src.MLA.','')

				elif len(imlaim[1])>0:
					algmthd = imlaim[1][0].split(' ')[1].replace('Src.MLA.','')

				else:
					algmthd = 0
					wx.MessageBox(_("Which Algorithm at Src.MLA used for this panel? Please check your source code!"))
					return 1
				#print(algmthd)
				if algmthd:
					infocod = self.getMData.AllML(
						" , MLAlgo where MLAlgo.MLAsrc = '%s' and MLAlgo.MLcod = MLinfo.MLcod" % algmthd)
					#print(infocod)
					if len(infocod) > 0:
						self.setMDate.Table = u'MLPane'
						self.setMDate.Additem(u' MLPid, MLPfile', [infocod[0][0], ifil])
						wx.MessageBox(_(u'Your source Add to list of Panel Successfully.'))
					else:
						wx.MessageBox(_("Please first Add your Algorithm to list then add Panel"))

			else:
				wx.MessageBox(_(u'Please Use <Apply> for add Algorithm file'))

		self.upd(event)
		#event.Skip()

	def opengeneratewin(self,lebls,data):
		dlg = wx.Dialog(self, -1)
		pnl = MyPanel5(dlg, lebls, data)
		dlg.SetSize((480, 190))
		dlg.SetLabel(_(u'Add MLA to List'))
		dlg.ShowModal()
		if pnl.acpt:
			algnm = pnl.fld1.GetValue()
			algcd = pnl.fld2.GetValue()
			algid = pnl.fld4.GetValue()
		else:
			algid = algnm = algcd = ''
		dlg.Destroy()

		return algid,algnm,algcd


	def addAl( self, event ):
		self.Frm = wx.Frame(self, style=wx.CAPTION | wx.CLOSE_BOX | wx.FRAME_FLOAT_ON_PARENT | wx.TAB_TRAVERSAL)
		#self.Pnl = PyPanel(self.Frm, GUI_PATH + 'Temp\\untitle.py')
		#self.Pnl = OS.SrcPanel(self.Frm, GUI_PATH + 'MLPane\\Untitle.py')
		self.Pnl = OS.SrcPanel(self.Frm, GUI_PATH + 'Temp\\Muntitle.py')
		self.Frm.SetMenuBar(OS.MyMenuBar1(u'AL'))
		self.Frm.SetSize((700, 560))
		self.Frm.SetLabel(u'untitle.py')
		self.Frm.Show()
		event.Skip()

	def edtAl( self, event ):
		chos = self.ChsBok.GetChoiceCtrl()
		ipg = self.ChsBok.GetSelection()
		chname = chos.GetString(ipg)
		#print(chos.GetString(chos.GetSelection()),chname)
		#print(ipg)
		Pnlid = self.getMData.MLPanid(chname)[0][0]
		#print(Pnlid)
		Pnlfil = self.getMData.MLPansFils(u' where MLPane.MLPid = %d '%Pnlid)[0][1]
		#print(Pnlfil)
		self.Frm = wx.Frame(self, style=wx.CAPTION | wx.CLOSE_BOX | wx.FRAME_FLOAT_ON_PARENT | wx.TAB_TRAVERSAL)
		#self.Pnl = PyPanel(self.Frm, GUI_PATH + 'MLPane\\'+Pnlfil+u'.py')
		#self.Pnl = OS.SrcPanel(self.Frm, SRC_PATH + 'mlp\\' + Pnlfil + u'.py')
		self.Pnl = OS.SrcPanel(self.Frm, Src_mlp + Pnlfil + u'.py')
		self.Frm.SetMenuBar(OS.MyMenuBar1(u'AL'))
		self.Frm.SetSize((700, 560))
		#self.Frm.SetLabel(SRC_PATH + 'mlp\\' + Pnlfil + u'.py')
		self.Frm.SetLabel(Src_mlp + Pnlfil + u'.py')
		self.Frm.Show()
		event.Skip()

	def delAl( self, event ):
		chos = self.ChsBok.GetChoiceCtrl()
		ipg = self.ChsBok.GetSelection()
		chname = chos.GetString(ipg)
		print(chname)
		Pnlid = self.getMData.MLPanid(chname)[0][0]
		print(Pnlid)
		answer = wx.MessageBox(_("Do you like delete Panel [%s] from list" % chname), style=wx.YES_NO)
		if answer == 2:
			self.setMDate.Table = 'MLPane'
			self.setMDate.Delitem(" MLPane.MLPid = %d "%Pnlid)
			wx.MessageBox(" Panel delete from list , you can see your file in All MLA source file in HDD")
			self.upd(event)
		event.Skip()

	def chgedpg( self, event ):
		event.Skip()

	def chgngpg( self, event ):
		event.Skip()

	def Splt1OnIdle( self, event ):
		self.Splt1.SetSashPosition( 255 )
		self.Splt1.Unbind( wx.EVT_IDLE )


###########################################################################
## Class MyPanel2
###########################################################################

class MyPanel2 ( wx.Panel ):

	def __init__( self, parent,dbfile, id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.Size( 667,300 ), style = wx.TAB_TRAVERSAL, name = wx.EmptyString ):
		wx.Panel.__init__ ( self, parent, id = id, pos = pos, size = size, style = style, name = name )

		Vsz = wx.BoxSizer( wx.VERTICAL )
		self.config = wx.GetApp().GetConfig()
		dbftype = Database_type[int(self.config.Read('DBtype'))]

		#self.dbfile = dbfile.split('\\')[-1]
		#self.idbfl = PG.Get(self.dbfile, u'', u'DBFields')
		self.idbfl2 = PG2.Get(dbfile, dbftype)
		conn = self.idbfl2.myengin.connect()
		Rprox = conn.execute('select * from sqlite_master')
		# print(Rprox.fetchall())
		self.dbdata = Rprox.fetchall()
		#self.dbdata = self.idbfl.GetFromDbf()

		Tfilds, Indxss = AnalizdbText2(self.dbdata)

		self.TablesChoices = [Tb for Tb in Tfilds]
		self.Tables = wx.Choice( self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, self.TablesChoices, 0 )
		self.Tables.SetSelection( 0 )
		Vsz.Add( self.Tables, 0, wx.ALL|wx.EXPAND, 5 )

		Hsz1 = wx.BoxSizer(wx.HORIZONTAL)
		#print(self.TablesChoices)
		self.fillist(self.TablesChoices[0])

		self.DLC1 = wx.dataview.DataViewListCtrl( self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz1.Add(self.DLC1, 1, wx.ALL | wx.EXPAND, 5)

		FLst1Choices = self.fldlst
		self.FLst1 = wx.CheckListBox(self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, FLst1Choices,
		                             wx.LB_ALWAYS_SB | wx.LB_HSCROLL )
		Hsz1.Add(self.FLst1, 0, wx.ALL | wx.EXPAND, 5)


		self.filldata()


		Vsz.Add( Hsz1, 1, wx.ALL|wx.EXPAND, 5 )

		Hsz2 = wx.BoxSizer(wx.HORIZONTAL)

		self.btn2 = wx.Button(self, wx.ID_ANY, _(u"Cancel"), wx.DefaultPosition, wx.DefaultSize, 0)
		Hsz2.Add(self.btn2, 0, wx.ALL, 5)

		self.btn1 = wx.Button(self, wx.ID_ANY, _(u"Apply"), wx.DefaultPosition, wx.DefaultSize, 0)
		Hsz2.Add(self.btn1, 0, wx.ALL, 5)

		Vsz.Add(Hsz2, 0, wx.ALIGN_CENTER_HORIZONTAL, 5)


		self.SetSizer( Vsz )
		self.Layout()

		# Connect Events
		self.Tables.Bind(wx.EVT_CHOICE, self.chng)
		self.DLC1.Bind( wx.dataview.EVT_DATAVIEW_ITEM_ACTIVATED, self.slctit, id = wx.ID_ANY )
		#self.DLC1.Bind( wx.dataview.EVT_DATAVIEW_ITEM_CONTEXT_MENU, self.domenu, id = wx.ID_ANY )
		self.DLC1.Bind( wx.dataview.EVT_DATAVIEW_SELECTION_CHANGED, self.slctit, id = wx.ID_ANY )
		self.btn2.Bind(wx.EVT_BUTTON, self.cancl)
		self.btn1.Bind(wx.EVT_BUTTON, self.aplyit)

	def __del__( self ):
		pass

	# Virtual event handlers, overide them in your derived class
	def fillist(self, Table):
		#print(type(Table))
		self.filds = []
		Tfilds, Indxss = AnalizdbText2(self.dbdata)
		#self.filds = self.idbfl.GetFromString(u"Select * from %s " % Table)
		self.filds = self.idbfl2.GetFromString(u"Select * from %s " % Table)
		#print(self.filds, Tfilds[Table])
		#print([fld[0] for fld in Tfilds[Table]])
		self.fldlst = [fld[0] for fld in Tfilds[Table]]


	def filldata(self):
		self.DLC1.ClearColumns()
		self.DLC1.DeleteAllItems()

		for f1 in self.fldlst:
			self.DLC1.AppendTextColumn(f1, width=-1, align=wx.ALIGN_LEFT)

		for data in self.filds:
			DD = ()
			for d in data:
				DD = DD + (str(d),)
			self.DLC1.AppendItem(DD)

	def chng(self, event):
		ichos = self.Tables.GetSelection()
		#print(self.TablesChoices[ichos])
		self.fillist(self.TablesChoices[ichos])
		self.filldata()
		#print(self.FLst1.GetItems())
		self.FLst1.Clear()
		self.FLst1.SetItems(self.fldlst)
		event.Skip()

	def slctit( self, event ):
		event.Skip()

	def cancl( self, event ):
		q = self.GetParent()
		q.Close()
		#event.Skip()

	def aplyit( self, event ):
		self.mydata = []
		#self.my_chois_fild = self.FLst1.GetCheckedItems()
		self.my_chois_fild = self.FLst1.GetCheckedStrings()
		for data in self.filds:
			DD = ()
			for ii in range(len(data)):
				if ii in  self.FLst1.GetCheckedItems():
					DD = DD + (data[ii],)
			self.mydata.append(DD)

		q = self.GetParent()
		q.Close()
		event.Skip()


###########################################################################
## Class MyPanel3
###########################################################################

class MyPanel3 ( wx.Panel ):

	def __init__( self, parent, fileini, txtini, id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.Size( 382,381 ), style = wx.TAB_TRAVERSAL, name = wx.EmptyString ):
		wx.Panel.__init__ ( self, parent, id = id, pos = pos, size = size, style = style, name = name )

		Vsz = wx.BoxSizer( wx.VERTICAL )

		self.titr = wx.StaticText( self, wx.ID_ANY, fileini, wx.DefaultPosition, wx.DefaultSize, 0 )
		self.titr.Wrap( -1 )

		Vsz.Add( self.titr, 0, wx.ALL|wx.EXPAND, 5 )

		self.inifil = wx.TextCtrl( self, wx.ID_ANY, txtini, wx.DefaultPosition, wx.DefaultSize, wx.HSCROLL|wx.TE_MULTILINE|wx.TE_WORDWRAP )
		Vsz.Add( self.inifil, 1, wx.ALL|wx.EXPAND, 5 )


		self.SetSizer( Vsz )
		self.Layout()

	def __del__( self ):
		pass

###########################################################################
## Class MyPanel4
###########################################################################

class MyPanel4 ( wx.Panel ):

	def __init__( self, parent, id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.Size( 370,200 ), style = wx.TAB_TRAVERSAL, name = wx.EmptyString ):
		wx.Panel.__init__ ( self, parent, id = id, pos = pos, size = size, style = style, name = name )

		bSizer1 = wx.BoxSizer( wx.VERTICAL )

		bSizer2 = wx.BoxSizer( wx.VERTICAL )

		self.RBtn1 = wx.RadioButton( self, wx.ID_ANY, u"Database (Engain type)", wx.DefaultPosition, wx.DefaultSize, 0 )
		#self.RBtn1.SetValue(True)
		bSizer2.Add( self.RBtn1, 1, wx.ALL|wx.EXPAND, 5 )

		self.RBtn2 = wx.RadioButton( self, wx.ID_ANY, u"Data Entry (Svc, Excel, Matlab, etc...)", wx.DefaultPosition, wx.DefaultSize, 0 )
		bSizer2.Add( self.RBtn2, 1, wx.ALL|wx.EXPAND, 5 )

		self.RBtn3 = wx.RadioButton( self, wx.ID_ANY, u"Media and Stream (Picture, Sound , Video, etc...)", wx.DefaultPosition, wx.DefaultSize, 0 )
		bSizer2.Add( self.RBtn3, 1, wx.ALL|wx.EXPAND, 5 )

		self.RBtn4 = wx.RadioButton( self, wx.ID_ANY, u"Other format and data", wx.DefaultPosition, wx.DefaultSize, 0 )
		bSizer2.Add( self.RBtn4, 1, wx.ALL|wx.EXPAND, 5 )


		bSizer1.Add( bSizer2, 1, wx.EXPAND, 5 )

		bSizer3 = wx.BoxSizer( wx.VERTICAL )

		self.Btn = wx.Button( self, wx.ID_ANY, u"My Choice", wx.DefaultPosition, wx.DefaultSize, 0 )
		bSizer3.Add( self.Btn, 0, wx.ALL, 5 )


		bSizer1.Add( bSizer3, 0, wx.ALIGN_CENTER_HORIZONTAL, 5 )


		self.SetSizer( bSizer1 )
		self.Layout()

		# Connect Events
		self.Btn.Bind( wx.EVT_BUTTON, self.doit )

	def __del__( self ):
		pass


	# Virtual event handlers, overide them in your derived class
	def doit( self, event ):
		q = self.GetParent()
		q.Close()


###########################################################################
## Class MyPanel5
###########################################################################

class MyPanel5 ( wx.Panel ):

	def __init__( self, parent,lebls,data, id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.Size( 481,188 ), style = wx.TAB_TRAVERSAL, name = wx.EmptyString ):
		wx.Panel.__init__ ( self, parent, id = id, pos = pos, size = size, style = style, name = name )

		Vsz1 = wx.BoxSizer( wx.VERTICAL )

		Hsz1 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl1 = wx.StaticText( self, wx.ID_ANY, lebls[0], wx.DefaultPosition, wx.Size( 110,-1 ), wx.ALIGN_CENTER_HORIZONTAL )
		self.lbl1.Wrap( -1 )

		Hsz1.Add( self.lbl1, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.fld1 = wx.TextCtrl( self, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz1.Add( self.fld1, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.lbl4 = wx.StaticText(self, wx.ID_ANY, _(u"Alg. id"), wx.DefaultPosition, wx.DefaultSize, 0)
		self.lbl4.Wrap(-1)
		Hsz1.Add(self.lbl4, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		self.fld4 = wx.TextCtrl(self, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.Size(70, -1), 0)
		Hsz1.Add(self.fld4, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		Vsz1.Add( Hsz1, 1, wx.EXPAND, 5 )

		Hsz2 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl2 = wx.StaticText( self, wx.ID_ANY, lebls[1], wx.DefaultPosition, wx.Size( 110,-1 ), wx.ALIGN_CENTER_HORIZONTAL )
		self.lbl2.Wrap( -1 )

		Hsz2.Add( self.lbl2, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.fld2 = wx.TextCtrl( self, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.Size( 70,-1 ), 0 )
		self.fld2.SetToolTip(_(u"Example: GD  EN  GLM  MLE"))
		Hsz2.Add( self.fld2, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.lbl3 = wx.StaticText( self, wx.ID_ANY, lebls[2], wx.DefaultPosition, wx.Size( 95,-1 ), wx.ALIGN_CENTER_HORIZONTAL )
		self.lbl3.Wrap( -1 )

		Hsz2.Add( self.lbl3, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.fld3 = wx.TextCtrl( self, wx.ID_ANY, str(data[0]), wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz2.Add( self.fld3, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz1.Add( Hsz2, 1, wx.EXPAND, 5 )


		Hsz4 = wx.BoxSizer( wx.HORIZONTAL )

		self.btn1 = wx.Button( self, wx.ID_ANY, _(u"Cancel"), wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz4.Add( self.btn1, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.btn2 = wx.Button( self, wx.ID_ANY, _(u"Apply"), wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz4.Add( self.btn2, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz1.Add( Hsz4, 0, wx.ALIGN_RIGHT, 5 )


		self.SetSizer( Vsz1 )
		self.Layout()

		# Connect Events
		self.btn1.Bind( wx.EVT_BUTTON, self.cncl )
		self.btn2.Bind( wx.EVT_BUTTON, self.aply )

	def __del__( self ):
		pass


	# Virtual event handlers, overide them in your derived class
	def cncl( self, event ):
		self.acpt = False
		q = self.GetParent()
		q.Close()

	def aply( self, event ):
		self.acpt = True
		q = self.GetParent()
		q.Close()






# In the name of God
# ! use/bin/env python

import os
import sqlite3

import wx

from Config.Init import *
from wx import MessageBox, OK, ICON_WARNING

from .dbinterface import  *

class SFDB(object):
	def __init__(self, database=':memory:',**kwargs):
		'''

		:param database:
		:param dbpath:
		:param kwargs: user pswrd host
		'''
		self.kwarg = kwargs
		self.database = database
		self.infacecon = self.Getinterface(**kwargs)
		self.connect()

	def Getinterface(self,**kwargs):
		'''

		:param kwargs: user, pswrd, host
		:return: interface connection to database
		'''
		#print(kwargs,self.kwarg)
		self.config = wx.GetApp().GetConfig()
		infaceid = self.config.Read('DBtype')
		myinface = Database_type[int(infaceid)]
		if myinface == 'sqlite':
			return ForSqlitDb(self.database)
		if myinface == 'mysql':
			return ForMySqldb(self.database,kwargs['user'],kwargs['pswrd'],kwargs['host'])
		if myinface == 'postgresql':
			return ForPostgrSql(self.database,kwargs['user'],kwargs['pswrd'],kwargs['host'])
		if myinface == 'oracle':
			return ForOraclSqldb(self.database,kwargs['user'],kwargs['pswrd'],kwargs['host'])
		if myinface == 'sqlserver':
			return ForMsSqlSrv(self.database,kwargs['user'],kwargs['pswrd'],kwargs['host'])


	def connect(self):
		# print self.database
		try:
			self.connection = self.infacecon #.connect(self.database)
			self.cursor = self.connection.cursor()
		except:
			# print( 'No Database find')
			MessageBox(u'No Database find', u'Error', OK | ICON_WARNING)

		self.connected = True
		self.statement = ''
		return self.connection

	def close(self):
		self.commit()
		self.connection.close()
		self.connected = False

	def commit(self):
		return self.connection.commit()

	def execute(self, statments):
		# with self.connect():
		self.cursor.execute(statments)
		#return self.fetchall()

	def execute1(self, statments, *data):
		if len(data) > 0:
			self.cursor.execute(statments, data[0])
		#self.commit()
		#return self.fetchall()

	def execone(self, statments, *data):
		if data == None:
			self.cursor.execute(statments)
		else:
			self.cursor.execute(statments, data[0])
		#return self.fetchone()

	def executemany(self, statments, *data):
		if data == None:
			return self.cursor.executemany(statments)
		else:
			return self.cursor.executemany(statments, data[0])

	def execuetscript(self, statments):
		return self.cursor.executescript(statments)

	def total_changes(self):
		pass

	def rollback(self):
		return self.cursor.rollback()

	def fetchone(self):
		return self.cursor.fetchone()

	def fetchall(self):
		return self.cursor.fetchall()

	def fetchmany(self, size):
		return self.cursor.fetchmany()

class SQLite(object):
	def __init__(self, tables, fields, values):
		self.tables = tables
		self.fields = fields
		self.values = values

	def create(self, **karg):
		sql = 'create table {t} ({f} {p})'.format(t=str(self.tables), f=str(self.fields), p=str(self.values))
		return sql

	def insert(self, **karg):
		sql = 'insert into ' + str(self.tables)
		sql = sql + '(' + str(self.fields) + ')'

		sql = sql + ' values ' + '(' + '?,' * (len(self.fields.split(',')) - 1) + '?)'
		# print sql
		return sql

	def select(self, *arg, **karg):
		sql = ' select ' + self.fields + ' from ' + self.tables
		# print sql
		return sql

	def select1(self, *arg, **karg):
		sql = ' select distinct' + self.fields + ' from ' + self.tables + ' where ' + self.values
		# print sql
		return sql

	def update(self, **karg):
		sql = ' update ' + self.tables + ' set ' + self.fields
		# print sql
		return sql

	def update2(self, **karg):
		sql = ' update ' + self.tables + ' set ' + self.fields + ' where ' + self.values
		return sql

	def delete(self, **karg):
		sql = ' delete from ' + self.tables + ' where ' + self.values
		return sql

	def delall(self, **karg):
		# sql = ' delete from '+self.tables+' where '+self.values
		sql = " delete from {t} ".format(t=self.tables)
		return sql

class MySQLs(object):
	def __init__(self, tables, fields, values):
		self.tables = tables
		self.fields = fields
		self.values = values

	def create(self, **karg):
		sql = 'CREATE TABLE {t} ({f} {p})'.format(t=str(self.tables), f=str(self.fields), p=str(self.values))
		return sql

	def insert(self, **karg):
		sql = 'INSERT INTO ' + str(self.tables)
		sql = sql + '(' + str(self.fields) + ')'

		sql = sql + ' VALUES ' + '(' + '%s,' * (len(self.fields.split(',')) - 1) + '%s)'
		# print sql
		return sql

	def select(self, *arg, **karg):
		sql = ' SELECT ' + self.fields + ' FROM ' + self.tables
		# print sql
		return sql

	def select1(self, *arg, **karg):
		sql = ' SELECT DISTINCT' + self.fields + ' FROM ' + self.tables + ' WHERE ' + self.values
		# print sql
		return sql

	def update(self, **karg):
		sql = ' UPDATE ' + self.tables + ' SET ' + self.fields
		# print sql
		return sql

	def update2(self, **karg):
		sql = ' UPDATE ' + self.tables + ' SET ' + self.fields + ' WHERE ' + self.values
		return sql

	def delete(self, **karg):
		sql = ' DELETE FROM ' + self.tables + ' WHERE ' + self.values
		return sql

	def delall(self, **karg):
		# sql = ' delete from '+self.tables+' where '+self.values
		sql = " DELETE FROM {t} ".format(t=self.tables)
		return sql


def MyDB_Path(database):
	if chkengin() == 2 or chkengin() == 3:
		config = wx.GetApp().GetConfig()
		iusr = config.Read('DBtype.Usr')
		ipwd = config.Read('DBtype.Pwd')
		ihst = config.Read('DBtype.Hst')
		#print(uphstr.split(' '))
		return SFDB(database,user=iusr,pswrd=ipwd,host=ihst)
	else:
		return SFDB(database)

def MySrc_db_Path(database, user='',pswrd='',host=''):
	return SFDB(database,user=user,pswrd=pswrd,host=host)

def chkengin():
	config = wx.GetApp().GetConfig()
	infaceid = config.Read('DBtype')
	return int(infaceid)


def wxsqsel(database, tabels, fields='*', condition=''):

	Mydb = MyDB_Path(database)
	Mydb.connect()
	if chkengin() == 1:
		sql = SQLite(tabels, fields, condition)
		sql1 = sql.select(fields, tabels)
	if chkengin() > 1:
		sql = MySQLs(tabels, fields, condition)
		sql1 = sql.select(fields, tabels)
	Mydb.execute(sql1)
	mylist = Mydb.fetchone()
	return mylist


def wxsqsel1(database, tabels, fields='*', condition=''):
	Mydb = MyDB_Path(database)
	Mydb.connect()
	if chkengin() == 1:
		sql = SQLite(tabels, fields, values=condition)
		sql1 = sql.select1(fields, tabels, values=condition)
	if chkengin() > 1:
		sql = MySQLs(tabels, fields, values=condition)
		sql1 = sql.select1(fields, tabels, values=condition)

	# print sql1
	Mydb.execute(sql1)
	mylist = Mydb.fetchall()
	return mylist

def wxsqsel2(database, tabels, fields='*'):
	Mydb = MyDB_Path(database)
	Mydb.connect()
	# print sql1
	Mydb.execute1(tabels, fields)
	mylist = Mydb.fetchall()
	return mylist

def wxsqltxt(database, text):
	# global MAP
	Mydb = MyDB_Path(database)
	Mydb.execute(text)
	mylist = Mydb.fetchall()
	return mylist


def wxsqins(database, tabels, fields, data):
	# global MAP
	Mydb = MyDB_Path(database)
	if chkengin() == 1:
		sql = SQLite(tabels, fields, values=data)
		sql1 = sql.insert()
		#print( sql1, data )
	if chkengin() > 1:
		sql = MySQLs(tabels, fields, values=data)
		sql1 = sql.insert()
	mylist = Mydb.execone(sql1, data)
	Mydb.commit()
	Mydb.close()
	# print mylist
	return mylist


def wxsqins2(database, tabels, fields, data):
	Mydb = MyDB_Path(database)
	if chkengin() == 1:
		sql = SQLite(tabels, fields, values=data)
		sql1 = sql.insert()
	# print( sql1, data )
	if chkengin() > 1:
		sql = MySQLs(tabels, fields, values=data)
		sql1 = sql.insert()
	mylist = Mydb.executemany(sql1, data)
	# Mydb.commit()
	Mydb.close()
	# print mylist
	return mylist

def wxsqins3(database, tabels, fields, data):
	# global MAP
	Mydb = MyDB_Path(database)
	if chkengin() == 1:
		sql = SQLite(tabels, fields, values=data)
		sql1 = sql.insert()
		#print( sql1, data )
	if chkengin() > 1:
		sql = MySQLs(tabels, fields, values=data)
		sql1 = sql.insert()
	mylist = Mydb.execute1(sql1, data)
	Mydb.commit()
	Mydb.close()
	# print mylist
	return mylist


def wxsqlup(database, tabels, fields, data):
	# global MAP
	Mydb = MyDB_Path(database)
	if chkengin() == 1:
		sql = SQLite(tabels, fields, values=data)
		sql1 = sql.update()
	if chkengin() > 1:
		sql = MySQLs(tabels, fields, values=data)
		sql1 = sql.update()

	# print sql
	# print sql1
	mylist = Mydb.execone(sql1, data)
	Mydb.commit()
	Mydb.close()
	# print mylist
	return mylist


def wxsqlup2(database, tabels, fields, data):
	Mydb = MyDB_Path(database)
	if chkengin() == 1:
		sql = SQLite(tabels, fields, values=data)
		sql1 = sql.update2()
	if chkengin() > 1:
		sql = MySQLs(tabels, fields, values=data)
		sql1 = sql.update2()

	mylist = Mydb.executemany(sql1, data)
	# Mydb.commit()
	Mydb.close()
	# print mylist
	return mylist


def wxsqdel(database, tabels, data):
	# global MAP
	Mydb = MyDB_Path(database)
	if chkengin() == 1:
		sql = SQLite(tabels, fields='', values=data)
		sql1 = sql.delete()
	if chkengin() > 1:
		sql = MySQLs(tabels, fields='', values=data)
		sql1 = sql.delete()

	# print sql
	# print sql1
	mylist = Mydb.execute(sql1)
	Mydb.commit()
	Mydb.close()
	# print mylist
	return mylist


def wxsqdall(database, tabels):
	Mydb = MyDB_Path(database)
	if chkengin() == 1:
		sql = SQLite(tabels, fields='', values='')
		sql1 = sql.delall()
	if chkengin() > 1:
		sql = MySQLs(tabels, fields='', values='')
		sql1 = sql.delall()
	mylist = Mydb.execute(sql1)
	# Mydb.commit()
	Mydb.close()
	# print mylist
	return mylist


def wxsqsnd(database, tabel, field1, field2, data):
	'''
	Select field1 from table where field2 = data
	'''
	# global MAP
	Mydb = MyDB_Path(database)
	mylist = Mydb.execute(
		'select ' + tabel + '.' + field1 + ' from ' + tabel + ' where ' + tabel + '.' + field2 + " = '%s' " % data)
	# print mylist
	return mylist



# -*- coding: utf-8 -*-

###########################################################################
## Python code generated with wxFormBuilder (version Oct 26 2018)
## http://www.wxformbuilder.org/
##
## PLEASE DO *NOT* EDIT THIS FILE!
###########################################################################

import wx
import wx.xrc
import wx.dataview

import importlib

from Config.Init import *
import Database.MenuSet2 as MS
from GUI.AuiPanel.PAui import *
import Res.Allicons as icon

_ = wx.GetTranslation

###########################################################################
## Class MyPanel5
###########################################################################

class MyPanel1 ( wx.Panel ):

	def __init__( self, parent, id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.Size( 557,450 ), style = wx.TAB_TRAVERSAL, name = wx.EmptyString ):
		wx.Panel.__init__ ( self, parent, id = id, pos = pos, size = size, style = style, name = name )

		Vsz1 = wx.BoxSizer( wx.VERTICAL )

		self.Splt1 = wx.SplitterWindow( self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.SP_3D|wx.SP_LIVE_UPDATE|wx.SP_NO_XP_THEME|wx.SP_THIN_SASH )
		#self.Splt1.SetSashGravity( -1 )
		self.Splt1.Bind( wx.EVT_IDLE, self.Splt1OnIdle )

		self.P1 = wx.Panel( self.Splt1, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.TAB_TRAVERSAL )
		Vsz2 = wx.BoxSizer( wx.VERTICAL )

		self.lbl1 = wx.StaticText( self.P1, wx.ID_ANY, _(u"List of Panes:"), wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lbl1.Wrap( -1 )

		Vsz2.Add( self.lbl1, 0, wx.ALL|wx.EXPAND, 5 )

		self.DVC1 = wx.dataview.TreeListCtrl( self.P1, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, 0 )
		self.Col1 = self.DVC1.AppendColumn( _(u"ID"), 75, wx.ALIGN_LEFT, wx.COL_RESIZABLE )
		self.Col2 = self.DVC1.AppendColumn( _(u"Name Pane"), 158, wx.ALIGN_LEFT, wx.COL_RESIZABLE )
		Vsz2.Add( self.DVC1, 1, wx.ALL|wx.EXPAND, 5 )

		self.MyMenu = MS.GetData(u'Menu2.db', u'')
		self.DoMenu = MS.SetData(u'', u'', u'')

		self.filllist()

		self.newpen = False
		self.s1 = 'Dock;FTTTTT'
		self.s2 = '-1;-1;0;0'
		self.bst_siz = '-1;-1'
		self.min_siz = '-1;-1'
		self.max_siz = '-1;-1'

		Hsz1 = wx.BoxSizer( wx.HORIZONTAL )

		self.btn1 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )

		#self.btn1.SetBitmap(wx.Bitmap( ICON16_PATH + u'add.png', wx.BITMAP_TYPE_ANY ) )
		self.btn1.SetBitmap(icon.add.GetBitmap())
		self.btn1.SetToolTip(_(u"Add"))
		Hsz1.Add( self.btn1, 0, wx.ALL, 5 )

		self.btn2 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )

		#self.btn2.SetBitmap( wx.Bitmap( ICON16_PATH + u'edit_button.png', wx.BITMAP_TYPE_ANY ) )
		self.btn2.SetBitmap(icon.edit_button.GetBitmap())
		self.btn2.SetToolTip(_(u"Edit"))
		Hsz1.Add( self.btn2, 0, wx.ALL, 5 )

		self.btn3 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )

		#self.btn3.SetBitmap( wx.Bitmap( ICON16_PATH + u'delete.png', wx.BITMAP_TYPE_ANY ) )
		self.btn3.SetBitmap(icon.delete.GetBitmap())
		self.btn3.SetToolTip(_(u"Delete"))
		Hsz1.Add( self.btn3, 0, wx.ALL, 5 )

		self.btn4 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )

		#self.btn4.SetBitmap( wx.Bitmap( ICON16_PATH + u'watch_window.png', wx.BITMAP_TYPE_ANY ) )
		self.btn4.SetBitmap(icon.watch_window.GetBitmap())
		self.btn4.SetToolTip(_(u"Show"))
		Hsz1.Add( self.btn4, 0, wx.ALL, 5 )

		self.btn5 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )

		#self.btn5.SetBitmap( wx.Bitmap( ICON16_PATH + u'update.png', wx.BITMAP_TYPE_ANY ) )
		self.btn5.SetBitmap(icon.update.GetBitmap())
		self.btn5.SetToolTip(_(u"Update"))
		Hsz1.Add( self.btn5, 0, wx.ALL, 5 )

		self.btn6 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )

		#self.btn6.SetBitmap( wx.Bitmap( ICON16_PATH + u'information.png', wx.BITMAP_TYPE_ANY ) )
		self.btn6.SetBitmap(icon.information.GetBitmap())
		self.btn6.SetToolTip(_(u"Info"))
		Hsz1.Add( self.btn6, 0, wx.ALL, 5 )

		self.btn7 = wx.BitmapButton(self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW | 0)

		#self.btn7.SetBitmap(wx.Bitmap(ICON16_PATH + u'accept_button.png', wx.BITMAP_TYPE_ANY))
		self.btn7.SetBitmap(icon.accept_button.GetBitmap())
		self.btn7.SetToolTip(_(u"Apply"))
		Hsz1.Add(self.btn7, 0, wx.ALL, 5)


		Vsz2.Add( Hsz1, 0, wx.ALIGN_CENTER_HORIZONTAL, 5 )


		self.P1.SetSizer( Vsz2 )
		self.P1.Layout()
		Vsz2.Fit( self.P1 )
		self.P2 = wx.Panel( self.Splt1, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.TAB_TRAVERSAL )
		Vsz3 = wx.BoxSizer( wx.VERTICAL )

		self.titr = wx.StaticText( self.P2, wx.ID_ANY, _(u"Pane Info:"), wx.DefaultPosition, wx.DefaultSize, 0 )
		self.titr.Wrap( -1 )

		Vsz3.Add( self.titr, 0, wx.ALL|wx.EXPAND, 5 )

		Hsz2 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl2 = wx.StaticText( self.P2, wx.ID_ANY, _(u"ID"), wx.DefaultPosition, wx.Size( 45,-1 ), 0 )
		self.lbl2.Wrap( -1 )

		Hsz2.Add( self.lbl2, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.fld1 = wx.TextCtrl( self.P2, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.Size( 50,-1 ), 0 )
		Hsz2.Add( self.fld1, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.lbl3 = wx.StaticText( self.P2, wx.ID_ANY, _(u"Access"), wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lbl3.Wrap( -1 )

		Hsz2.Add( self.lbl3, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.fld2 = wx.TextCtrl( self.P2, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.Size( 50,-1 ), 0 )
		Hsz2.Add( self.fld2, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.codgnr = wx.Button( self.P2, wx.ID_ANY, u"...", wx.DefaultPosition, wx.DefaultSize, wx.BU_EXACTFIT )
		Hsz2.Add( self.codgnr, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz3.Add( Hsz2, 1, wx.EXPAND, 5 )

		Hsz3 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl4 = wx.StaticText( self.P2, wx.ID_ANY, _(u"Name"), wx.DefaultPosition, wx.Size( 45,-1 ), 0 )
		self.lbl4.Wrap( -1 )

		Hsz3.Add( self.lbl4, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.fld3 = wx.TextCtrl( self.P2, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz3.Add( self.fld3, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz3.Add( Hsz3, 1, wx.EXPAND, 5 )

		Hsz4 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl5 = wx.StaticText( self.P2, wx.ID_ANY, _(u"Caption"), wx.DefaultPosition, wx.Size( 45,-1 ), 0 )
		self.lbl5.Wrap( -1 )

		Hsz4.Add( self.lbl5, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.fld4 = wx.TextCtrl( self.P2, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz4.Add( self.fld4, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz3.Add( Hsz4, 1, wx.EXPAND, 5 )

		Hsz6 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl7 = wx.StaticText( self.P2, wx.ID_ANY, _(u"Setting"), wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lbl7.Wrap( -1 )

		Hsz6.Add( self.lbl7, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.stgbtn = wx.Button( self.P2, wx.ID_ANY, u"...", wx.DefaultPosition, wx.DefaultSize, wx.BU_EXACTFIT )
		Hsz6.Add( self.stgbtn, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz3.Add( Hsz6, 1, wx.EXPAND, 5 )

		self.fld6 = wx.TextCtrl( self.P2, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, wx.TE_MULTILINE )
		Vsz3.Add( self.fld6, 1, wx.ALL|wx.EXPAND, 5 )

		self.lin1 = wx.StaticLine( self.P2, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.LI_HORIZONTAL )
		Vsz3.Add( self.lin1, 0, wx.EXPAND |wx.ALL, 5 )

		Hsz7 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl12 = wx.StaticText( self.P2, wx.ID_ANY, _(u"Size"), wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lbl12.Wrap( -1 )

		Hsz7.Add( self.lbl12, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.wht = wx.TextCtrl( self.P2, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.Size( 50,-1 ), 0 )
		Hsz7.Add( self.wht, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.hgt = wx.TextCtrl( self.P2, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.Size( 50,-1 ), 0 )
		Hsz7.Add( self.hgt, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.sizbtn = wx.Button( self.P2, wx.ID_ANY, _(u"Other Size"), wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz7.Add( self.sizbtn, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz3.Add( Hsz7, 0, wx.ALIGN_CENTER_HORIZONTAL, 5 )

		Hsz8 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl10 = wx.StaticText( self.P2, wx.ID_ANY, _(u"resize"), wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lbl10.Wrap( -1 )

		Hsz8.Add( self.lbl10, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		chs1Choices = [ u"Resizable", u"Fixed" ]
		self.chs1 = wx.Choice( self.P2, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, chs1Choices, 0 )
		self.chs1.SetSelection( 0 )
		Hsz8.Add( self.chs1, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.lbl6 = wx.StaticText( self.P2, wx.ID_ANY, _(u"dock"), wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lbl6.Wrap( -1 )

		Hsz8.Add( self.lbl6, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		chs2Choices = [ u"Dock", u"Float" ]
		self.chs2 = wx.Choice( self.P2, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, chs2Choices, 0 )
		self.chs2.SetSelection( 0 )
		Hsz8.Add( self.chs2, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz3.Add( Hsz8, 0, wx.ALIGN_CENTER_HORIZONTAL, 5 )

		Hsz9 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl11 = wx.StaticText( self.P2, wx.ID_ANY, _(u"Docking"), wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lbl11.Wrap( -1 )

		Hsz9.Add( self.lbl11, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		chs3Choices = [ u"Top", u"Center", u"Left", u"Right", u"Bottom" ]
		self.chs3 = wx.Choice( self.P2, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, chs3Choices, 0 )
		self.chs3.SetSelection( 2 )
		Hsz9.Add( self.chs3, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.dokbtn = wx.Button(self.P2, wx.ID_ANY, u"...", wx.DefaultPosition, wx.DefaultSize, wx.BU_EXACTFIT)
		Hsz9.Add(self.dokbtn, 0, wx.ALL, 5)

		self.lbl13 = wx.StaticText(self.P2, wx.ID_ANY, _(u"Layer"), wx.DefaultPosition, wx.DefaultSize, 0)
		self.lbl13.Wrap(-1)

		Hsz9.Add(self.lbl13, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		self.lyrspn = wx.SpinCtrlDouble(self.P2, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.Size(40, -1),
		                                wx.ALIGN_CENTER_HORIZONTAL | wx.SP_ARROW_KEYS, 0, 9, 0.000000, 1)
		self.lyrspn.SetDigits(0)
		Hsz9.Add(self.lyrspn, 0, wx.ALL, 5)


		Vsz3.Add( Hsz9, 0, wx.ALIGN_CENTER_HORIZONTAL, 5 )

		self.lin2 = wx.StaticLine( self.P2, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.LI_HORIZONTAL )
		Vsz3.Add( self.lin2, 0, wx.EXPAND |wx.ALL, 5 )

		Hsz10 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl8 = wx.StaticText( self.P2, wx.ID_ANY, _(u"Program:"), wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lbl8.Wrap( -1 )

		Hsz10.Add( self.lbl8, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.probtn = wx.Button( self.P2, wx.ID_ANY, u"...", wx.DefaultPosition, wx.DefaultSize, wx.BU_EXACTFIT )
		self.probtn.SetToolTip( _(u"list of program can changed") )

		Hsz10.Add( self.probtn, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz3.Add( Hsz10, 1, wx.EXPAND, 5 )

		Vsz4 = wx.BoxSizer( wx.VERTICAL )

		self.prgfld = wx.TextCtrl( self.P2, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, 0 )
		Vsz4.Add( self.prgfld, 0, wx.ALL|wx.EXPAND, 5 )

		self.lbl9 = wx.StaticText( self.P2, wx.ID_ANY, _(u"Directory:"), wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lbl9.Wrap( -1 )

		Vsz4.Add( self.lbl9, 0, wx.ALL, 5 )


		Vsz3.Add( Vsz4, 1, wx.EXPAND, 5 )


		self.P2.SetSizer( Vsz3 )
		self.P2.Layout()
		Vsz3.Fit( self.P2 )
		self.Splt1.SplitVertically( self.P1, self.P2, 255 )
		Vsz1.Add( self.Splt1, 1, wx.EXPAND, 5 )


		self.SetSizer( Vsz1 )
		self.Layout()

		self.myInfo = wx.aui.AuiPaneInfo()

		# Connect Events
		#self.DVC1.Bind( wx.dataview.EVT_DATAVIEW_ITEM_ACTIVATED, self.slctmnu, id = wx.ID_ANY )
		self.DVC1.Bind( wx.dataview.EVT_DATAVIEW_SELECTION_CHANGED, self.actitm)
		self.btn1.Bind( wx.EVT_BUTTON, self.addit )
		self.btn2.Bind( wx.EVT_BUTTON, self.edtit )
		self.btn3.Bind( wx.EVT_BUTTON, self.delit )
		self.btn4.Bind( wx.EVT_BUTTON, self.prviw )
		self.btn5.Bind( wx.EVT_BUTTON, self.updat )
		self.btn6.Bind( wx.EVT_BUTTON, self.publc )
		self.btn7.Bind( wx.EVT_BUTTON, self.aplit )
		self.codgnr.Bind( wx.EVT_BUTTON, self.gnrcod )
		self.stgbtn.Bind( wx.EVT_BUTTON, self.stngpn )
		self.sizbtn.Bind( wx.EVT_BUTTON, self.otrsiz )
		self.chs1.Bind( wx.EVT_CHOICE, self.rezfix )
		self.chs2.Bind( wx.EVT_CHOICE, self.dokflt )
		self.chs3.Bind( wx.EVT_CHOICE, self.lrtbc )
		self.dokbtn.Bind(wx.EVT_BUTTON, self.dockabl)
		self.probtn.Bind( wx.EVT_BUTTON, self.prglst )

	def __del__( self ):
		pass


	# Virtual event handlers, overide them in your derived class
	def filllist(self):
		broot = self.DVC1.GetRootItem()
		mroot = self.DVC1.AppendItem(broot, 'AuiPanes')
		self.items = self.MyMenu.AllPanes()
		for itm in self.items:
			pnitm = self.DVC1.AppendItem(mroot, itm[1])
			self.DVC1.SetItemText(pnitm, 0, str(itm[0]))
			self.DVC1.SetItemText(pnitm, 1, itm[1])
		pass
	def actitm( self, event ):
		ps2 = self.DVC1.GetSelection()
		it2 =  self.DVC1.GetItemText(ps2,0)
		#print(ps2,it2)
		for tem in self.items:
			if int(it2) in tem:
				#print(tem)
				self.thspan = tem
				self.fillinfo(tem)

	def fillinfo(self, Data):
		#print(Data)
		self.fld1.SetValue(str(Data[0]))
		self.fld2.SetValue(Data[7])
		self.fld3.SetValue(Data[1])
		self.fld4.SetValue(Data[9])
		self.datastng = Data[10]
		#self.gnrsetting(self.datastng)
		self.fld6.SetValue(self.datastng)
		w,h = Data[3].split(';')
		self.wht.SetValue(w)
		self.hgt.SetValue(h)
		self.othrsiz = [Data[12],Data[13],Data[14]]

		self.chs1.SetStringSelection(Data[11])

		dokng,self.dokng = Data[15].split(';')
		self.chs2.SetStringSelection(dokng)

		self.chs3.SetStringSelection(Data[2])
		self.lyrspn.SetValue(Data[4])
		self.opsint = Data[16]

		if len(self.MyMenu.RunHdnl(Data[6])) > 0:
			mydir,myprgnm = self.MyMenu.RunHdnl(Data[6])[0]
			#print(mydir,myprgnm)
		else:
			mydir,myprgnm = self.NewPanePrg()

		self.prgfld.SetValue(myprgnm+'.py')
		self.lbl9.SetLabel(_(u"Directory: ")+mydir)

	def fillnull(self):
		data = (0,'','','-1;-1',0,'',50000,'','','','TTFFTTTFFFFT','','','','','Dock;FTTTTT','-1;-1;0;0')
		self.fillinfo(data)
		self.fld1.SetValue('')


	def slctmnu( self, event ):
		event.Skip()

	def addit( self, event ):
		self.fillnull()
		self.newpen = True
		event.Skip()

	def edtit( self, event ):
		Up1 = self.getdata()
		stng = self.fld6.GetValue()
		if Up1[0] != '':
			if self.prgfld.GetValue() != '':
				hndlid = self.findhndlr(self.prgfld.GetValue().replace('.py','')) #find handlerid

			mypan = self.MyMenu.getPane(Up1[0])
			codinfo = mypan[0][5]
			#print(Up1,mypan,codinfo)
			D1 = [ Up1[2], Up1[7], Up1[4], int(Up1[8]),  hndlid, Up1[1]]
			self.DoMenu.Table = u'pans'
			self.DoMenu.Upditem( ' panname = ? , pandok = ?, pansiz = ?, panlyr = ? , handlerid = ? , acclvlid = ? \
			                     Where panid = %d ' %int(Up1[0]) ,D1 )
			if self.chs2.GetStringSelection() != 'Dock':
				self.s1 = self.chs2.GetStringSelection()+';'+self.s1.split(';')[1]

			stng = self.fld6.GetValue()

			D2 = [ Up1[3], stng, Up1[5], self.bst_siz, self.min_siz, self.max_siz, self.s1, self.s2]
			self.DoMenu.Table = u'panifo'
			self.DoMenu.Upditem(u" caption = ?, setting = ?, resize = ?, bstsiz = ?, minsiz = ?, maxsiz = ?, docking = ?, position = ? \
			                       Where paninfoid = '%s' " %codinfo, D2)

			D3 = [ 1, 'FFFF', 1]
			self.DoMenu.Table = u'access'
			self.DoMenu.Upditem(u" userid = ? , acclvl = ? , disenable = ?   Where acclvlid = '%s' " % Up1[1], D3)

			wx.MessageBox(_(u'Pane is successful Update '))

			self.DVC1.DeleteAllItems()
			self.filllist()
			self.Refresh()

		event.Skip()

	def delit( self, event ):
		#print(self.getdata())
		D = self.getdata()
		for i in self.items:
			if i[0] == int(D[0]):
				Delitem = i
				#print(Delitem)
				self.DoMenu.Table = u'pans'
				self.DoMenu.Delitem(u' pans.panid = %d '% Delitem[0] )
				self.DoMenu.Table = u'panifo'
				self.DoMenu.Delitem(u' panifo.paninfoid = "%s" '% Delitem[8])
				self.DoMenu.Table = u'access'
				self.DoMenu.Delitem(u' access.acclvlid = "%s"' % Delitem[7])

				wx.MessageBox(_(u' Pane delete from application successful'))

		self.DVC1.DeleteAllItems()
		self.filllist()
		self.Refresh()

		event.Skip()

	def updat( self, event ):
		self.DVC1.DeleteAllItems()
		self.filllist()
		self.Refresh()
		event.Skip()

	def publc( self, event ):
		print(self.thspan)
		event.Skip()

	def prviw( self, event ):
		#mw = self.FindWindowByName('main')
		#mw.m_mgr.
		#print(self.fld3.GetValue())
		#a2 = 'Src.AUI.'+self.fld3.GetValue()
		a2 = 'Src.AUI.' + self.prgfld.GetValue().replace('.py','')
		try:
			m = importlib.import_module(a2)
			self.Frm = wx.Frame(self, -1, pos=wx.DefaultPosition, size=wx.DefaultSize)
			self.pnl = m.MyPanel1(self.Frm, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.TAB_TRAVERSAL)
			self.Frm.Show()
		except ImportError as error:
			wx.MessageBox(error)
			#print(error)
		event.Skip()

	def aplit( self, event ):
		#self.myInfo = wx.aui.AuiPaneInfo()
		Data1 = self.getdata()
		#print(Data1)
		#print(self.fld6.GetValue())
		stng = self.fld6.GetValue()
		#print(self.s1, self.s2)
		#print(self.fild)
		#print(self.bst_siz,self.min_siz,self.max_siz)
		if self.newpen:
			strng = 'abcdefghijklmnopqrstuvwxyz'
			codinfo = Data1[0]+strng[int(Data1[0][0])-1]+strng[int(Data1[0][1])]
			if self.prgfld.GetValue() == '':
				hndlid = 50000 + int(Data1[0])
				import shutil
				shutil.copyfile(GUI_PATH+'Temp'+SLASH+'tempane.py',Src_aui+Data1[2]+'.py')
			else:
				hndlid, hndldir = self.MyMenu.getHndlr(self.prgfld.GetValue().replace('.py',''))[0]
				if hndlid == '' or hndlid == None:
					hndlid == 50000

			D1 = [int(Data1[0]),Data1[2],Data1[7],Data1[4],int(Data1[8]),codinfo,hndlid,Data1[1]]
			self.DoMenu.Table = u'pans'
			self.DoMenu.Additem(u' panid, panname, pandok, pansiz, panlyr, paninfoid, handlerid, acclvlid ',D1)

			if self.chs2.GetStringSelection() != 'Dock':
				self.s1 = self.chs2.GetStringSelection()+';'+self.s1.split(';')[1]

			D2 = [codinfo,Data1[3],stng, Data1[5], self.bst_siz, self.min_siz, self.max_siz, self.s1, self.s2]
			self.DoMenu.Table = u'panifo'
			self.DoMenu.Additem(u' paninfoid, caption, setting, resize, bstsiz, minsiz, maxsiz, docking, position',D2)

			D3 = [Data1[1], 1, 'FFFF', 1]
			self.DoMenu.Table = u'access'
			self.DoMenu.Additem(u' acclvlid, userid, acclvl, disenable',D3)

			wx.MessageBox(_(u'A new Pane add to application '))

			self.DVC1.DeleteAllItems()
			self.filllist()
			self.Refresh()

			#createpenshow()

		else:
			wx.MessageBox(_(u'Please press Add bottom to make new pane'))
		event.Skip()

	def gnrcod( self, event ):
		strng = 'abcdefghijklmnopqrstuvwxyz'
		if len(self.items) > 0:
			lcod = self.items[-1][0]
		else:
			lcod = 10
		self.fld1.SetValue(str(int(lcod)+1))
		self.fld2.SetValue(str(int(lcod)+1)+'pn'+strng[(lcod+1)//10-1]+strng[(lcod+1)%10])


	def stngpn( self, event ):
		iwin = wx.Dialog(self, -1)
		pnl = MyPanel2(iwin,self.datastng)
		iwin.SetSize((500, 320))
		iwin.ShowModal()
		try:
			#print(pnl.e)
			self.gnrsetting(pnl.e)
			self.fild = self.crtsetsrt(pnl.e)
			self.fld6.SetValue(self.fild)
		except AttributeError:
			#print('Cancel it')
			#print(pnl.PGrid1.GetPropertyValues())
			self.gnrsetting(pnl.PGrid1.GetPropertyValues())
			self.fild = self.crtsetsrt(pnl.PGrid1.GetPropertyValues())
			self.fld6.SetValue(self.fild)

		iwin.Destroy()

	def otrsiz( self, event ):
		iwin = wx.Dialog(self, -1)
		pnl = MyPanel3(iwin,self.othrsiz)
		iwin.SetSize((400, 250))
		iwin.ShowModal()
		#print(pnl.PGrid1.GetPropertyValues())
		self.gnrsize(pnl.PGrid1.GetPropertyValues())
		self.crtsizsrt(pnl.PGrid1.GetPropertyValues())
		iwin.Destroy()

	def rezfix( self, event ):
		if self.chs1.GetSelection() == 1:
			self.wht.Disable()
			self.hgt.Disable()
		elif self.chs1.GetSelection() == 0:
			self.wht.Enable()
			self.hgt.Enable()


	def dokflt( self, event ):
		event.Skip()

	def lrtbc( self, event ):
		event.Skip()

	def dockabl(self, event):
		iwin = wx.Dialog(self, -1)
		pnl = MyPanel4(iwin,(self.dokng,self.opsint))
		iwin.SetSize((400, 350))
		iwin.ShowModal()
		#print(pnl.PGrid1.GetPropertyValues())
		self.gnrdock(pnl.PGrid1.GetPropertyValues(), self.chs2.GetStringSelection())
		self.s1, self.s2 = self.credoksrt(pnl.PGrid1.GetPropertyValues())
		iwin.Destroy()

	def prglst( self, event ):
		if wx.FindWindowByName(u'Program Develop') == None:
			if self.prgfld.GetValue() != '':
				#print(self.thspan)
				import DCC1.ProgDev2 as DP
				ifrm = wx.Frame(self, -1, style=wx.FRAME_FLOAT_ON_PARENT | wx.DEFAULT_FRAME_STYLE)
				pnl = DP.MyPanel1(ifrm,[self.GetParent(),self.prgfld.GetValue().replace('.py',''),self.thspan[6]])
				ifrm.SetSize((555, 500))
				ifrm.SetTitle(u'Program Develop')
				ifrm.Show()
				#print(ifrm.TransferDataFromWindow())
		else:
			wx.MessageBox(_("Double Program: Please Close Program Develop then Do this item"))
			pass

	def findhndlr(self, hndlrnm):
		if hndlrnm == '':
			return 50000
		else:
			codid, self.prgdir = self.MyMenu.getHndlr(hndlrnm)[0]
			return codid

	def NewPanePrg(self):
		Data = [50000,'tempane', '5555', '-1', -1, 500]
		self.DoMenu.Table = 'handler'
		self.DoMenu.Additem(' handlerid, prgname, prgdir, paramtr, public, prgno', Data)
		if not os.path.isfile(Src_aui+'tempane.py'):
			shutil.copyfile(GUI_PATH+'AuiPanel'+SLASH+'tempane.py',Src_aui+'tempane.py')

		return '5555','tempane'

	def getdata(self):
		D1 = self.fld1.GetValue()
		D2 = self.fld2.GetValue()
		D3 = self.fld3.GetValue()
		D4 = self.fld4.GetValue()
		#self.datastng = self.getseting()
		#self.fld6.SetValue('')
		#w, h = Data[3].split(';')
		w = self.wht.GetValue()
		h = self.hgt.GetValue()
		D5 = w+';'+h
		#self.othrsiz = self.getothrsiz()
		D6 = self.chs1.GetStringSelection()
		#dokng, self.dokng = Data[15].split(';')
		D7 = self.chs2.GetStringSelection()
		D8 = self.chs3.GetStringSelection()
		D9 = self.lyrspn.GetValue()
		#self.opsint = Data[16]
		return D1,D2,D3,D4,D5,D6,D7,D8,D9

	def getGnral(self):
		mydic = {}
		D = self.getdata()
		mydic['name'] = D[2]
		mydic['caption'] = D[3]
		mydic['fload_size'] = D[4]
		mydic['resize'] = D[5]
		mydic['dock'] = D[6]
		mydic['docking'] = D[7]
		mydic['layer'] = D[8]
		self.myInfo = AuiInfoGen1(mydic,self.myInfo)
		#return self.myInfo

	def gnrsetting(self, Data):
		self.myInfo = AuiInfoSet1(Data,self.myInfo)
		#return self.myInfo

	def gnrsize(self, Data):
		self.myInfo = AuiInfoSiz1(Data,self.myInfo)
		#return self.myInfo

	def gnrdock(self, Data, Dok):
		self.myInfo = AuiInfoDok1(Data, Dok,self.myInfo)
		#return self.myInfo

	def crtsetsrt(self, D):
		s = ''
		#print(D.values())
		for d in D.values():
			if d :
				s += 'T'
			else:
				s += 'F'
		#print(s)
		return s

	def crtsizsrt(self, D):
		self.bst_siz = str(D['best_size'].x)+';'+str(D['best_size'].y)
		self.min_siz = str(D['min_size'].x)+';'+str(D['min_size'].y)
		self.max_siz = str(D['max_size'].x)+';'+str(D['max_size'].y)

	def credoksrt(self, D):
		s1 = s2 = ''
		for d in D.values():
			if type(d) == list:
				s2 = str(d[0])+';'+str(d[1])
			elif type(d) == int:
				s2 += ';'+str(d)
			else:
				if d:
					s1 += 'T'
				else:
					s1 += 'F'
		s1 = self.chs2.GetStringSelection() + ';' + s1
		#print(s1,s2)
		return s1,s2


	def Splt1OnIdle( self, event ):
		self.Splt1.SetSashPosition( 255)
		self.Splt1.Unbind( wx.EVT_IDLE )




###########################################################################
## Class MyPanel2
###########################################################################
import wx.propgrid as pg


class MyPanel2 ( wx.Panel ):

	def __init__( self, parent,Data='', id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.Size( 500,342 ), style = wx.TAB_TRAVERSAL, name = wx.EmptyString ):
		wx.Panel.__init__ ( self, parent, id = id, pos = pos, size = size, style = style, name = name )

		Vsz1 = wx.BoxSizer( wx.VERTICAL )

		self.Item = []

		if Data != '':
			for D in Data:
				if D == 'T':
					self.Item.append(True)
				if D == 'F':
					self.Item.append(False)
		else:
			self.Item = [True,True,False,False,True,True,True,False,False,False,False,True]


		items = [('caption_visible',self.Item[0]),('close_button',self.Item[1]),('maximize_button',self.Item[2]),('minimize_button',self.Item[3]),
		         ('pine_button',self.Item[4]),('pane_border',self.Item[5]),('show',self.Item[6]),('gripper',self.Item[7]),('center_pane',self.Item[8]),
		         ('default_pane',self.Item[9]),('toolbar_pane',self.Item[10]),('moveable',self.Item[11]) ]


		self.PGrid1 = pg.PropertyGrid(self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.propgrid.PG_DEFAULT_STYLE|wx.propgrid.PG_SPLITTER_AUTO_CENTER|wx.propgrid.PG_TOOLTIPS)

		self.PGrid1.Append(pg.PropertyCategory(u"AUI Info", u"AUI Info"))

		for itm in items:
			#self.Item.append( self.PGrid1.Append( pg.BoolProperty( itm[0], itm[0], value=itm[1]) )  )
			self.PGrid1.Append(pg.BoolProperty(itm[0], itm[0], value=itm[1]))
			self.PGrid1.SetPropertyAttribute(itm[0],"UseCheckbox", True)


		Vsz1.Add( self.PGrid1, 1, wx.ALL|wx.EXPAND, 5 )

		Hsz1 = wx.BoxSizer( wx.HORIZONTAL )

		self.btn1 = wx.Button( self, wx.ID_ANY, _(u"Cancel"), wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz1.Add( self.btn1, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.btn2 = wx.Button( self, wx.ID_ANY, _(u"Ok"), wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz1.Add( self.btn2, 0, wx.ALL, 5 )


		Vsz1.Add( Hsz1, 0, wx.ALIGN_CENTER_HORIZONTAL, 5 )


		self.SetSizer( Vsz1 )
		self.Layout()

		# Connect Events
		self.btn1.Bind( wx.EVT_BUTTON, self.cncl )
		self.btn2.Bind( wx.EVT_BUTTON, self.okit )

	def __del__( self ):
		pass


	# Virtual event handlers, overide them in your derived class
	def cncl( self, event ):
		q = self.GetParent()
		q.Close()

	def okit( self, event ):
		self.e = self.PGrid1.GetPropertyValues()
		#print(self.e)
		q = self.GetParent()
		q.Close()


#################################################################################
##  Size Property Class
##
#################################################################################
class SizeProperty(pg.PGProperty):
	""" Demonstrates a property with few children.
    """
	def __init__(self, label, name = pg.PG_LABEL, value=wx.Size(0, 0)):
		pg.PGProperty.__init__(self, label, name)

		value = self._ConvertValue(value)

		self.AddPrivateChild( pg.IntProperty("Width", value=value.x) )
		self.AddPrivateChild( pg.IntProperty("Height", value=value.y) )

		self.m_value = value
		#print(self.m_value)

	def GetClassName(self):
		return self.__class__.__name__

	def DoGetEditorClass(self):
		return pg.PropertyGridInterface.GetEditorByName("TextCtrl")

	def RefreshChildren(self):
		size = self.m_value
		self.Item(0).SetValue( size.x )
		self.Item(1).SetValue( size.y )

	def _ConvertValue(self, value):
		""" Utility convert arbitrary value to a real wx.Size.

        """
		import collections
		if isinstance(value, collections.Sequence) or hasattr(value, '__getitem__'):
			value = wx.Size(*value)
		return value

	def ChildChanged(self, thisValue, childIndex, childValue):
		size = self._ConvertValue(self.m_value)
		if childIndex == 0:
			size.x = childValue
		elif childIndex == 1:
			size.y = childValue
		else:
			raise AssertionError

		return size


###########################################################################
## Class MyPanel3
###########################################################################

class MyPanel3 ( wx.Panel ):

	def __init__( self, parent, LData, id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.Size( 400,242 ), style = wx.TAB_TRAVERSAL, name = wx.EmptyString ):
		wx.Panel.__init__ ( self, parent, id = id, pos = pos, size = size, style = style, name = name )

		Vsz1 = wx.BoxSizer( wx.VERTICAL )
		#print(LData)
		if LData == ['','','']:
			bsz = wx.Size(-1,-1)
			mnz = wx.Size(-1,-1)
			mxz = wx.Size(-1,-1)
		else:
			a,b = LData[0].split(';')
			bsz = wx.Size(int(a),int(b))
			a, b = LData[1].split(';')
			mnz = wx.Size(int(a),int(b))
			a, b = LData[2].split(';')
			mxz = wx.Size(int(a),int(b))

		self.PGrid1 = pg.PropertyGrid(self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.propgrid.PG_DEFAULT_STYLE|wx.propgrid.PG_SPLITTER_AUTO_CENTER|wx.propgrid.PG_TOOLTIPS)
		self.Item1 = self.PGrid1.Append( pg.PropertyCategory( u"Other Size", u"Other Size" ) )


		self.Item2 = self.PGrid1.Append( SizeProperty( u"best_size", u"best_size", value=bsz ) )
		self.Item3 = self.PGrid1.Append( SizeProperty( u"min_size", u"min_size", value=mnz ) )
		self.Item4 = self.PGrid1.Append( SizeProperty( u"max_size", u"max_size", value=mxz ) )

		Vsz1.Add( self.PGrid1, 1, wx.ALL|wx.EXPAND, 5 )

		Hsz1 = wx.BoxSizer( wx.HORIZONTAL )

		self.btn1 = wx.Button( self, wx.ID_ANY, _(u"Cancel"), wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz1.Add( self.btn1, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.btn2 = wx.Button( self, wx.ID_ANY, _(u"Ok"), wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz1.Add( self.btn2, 0, wx.ALL, 5 )


		Vsz1.Add( Hsz1, 0, wx.ALIGN_CENTER_HORIZONTAL, 5 )


		self.SetSizer( Vsz1 )
		self.Layout()

		# Connect Events
		self.btn1.Bind( wx.EVT_BUTTON, self.cncl )
		self.btn2.Bind( wx.EVT_BUTTON, self.okit )

	def __del__( self ):
		pass


	# Virtual event handlers, overide them in your derived class
	def cncl( self, event ):
		q = self.GetParent()
		q.Close()

	def okit( self, event ):
		self.e = self.PGrid1.GetPropertyValues()
		q = self.GetParent()
		q.Close()

#################################################################################
##  Pos Property Class
##
#################################################################################
class PosProperty(pg.PGProperty):
    """ Demonstrates a property with few children.
    """
    def __init__(self, label, name = pg.PG_LABEL, value=wx.Position(0, 0)):
        pg.PGProperty.__init__(self, label, name)


        value = self._ConvertValue(value)

        self.AddPrivateChild( pg.IntProperty("X", value=value.Col) )
        self.AddPrivateChild( pg.IntProperty("Y", value=value.Row) )

        self.m_value = value
        #print(self.m_value)

    def GetClassName(self):
        return self.__class__.__name__

    def DoGetEditorClass(self):
        return pg.PropertyGridInterface.GetEditorByName("TextCtrl")

    def RefreshChildren(self):
        pos = self.m_value
        self.Item(0).SetValue( pos[0] )
        self.Item(1).SetValue( pos[1] )

    def _ConvertValue(self, value):
        """ Utility convert arbitrary value to a real wx.Size.
        """
        import collections
        if isinstance(value, collections.Sequence) or hasattr(value, '__getitem__'):
            value = wx.Position(*value)
        return value

    def ChildChanged(self, thisValue, childIndex, childValue):
        pos = self._ConvertValue(self.m_value)
        if childIndex == 0:
            pos.Row = childValue
        elif childIndex == 1:
            pos.Col = childValue
        else:
            raise AssertionError

        return pos


###########################################################################
## Class MyPanel4
###########################################################################

class MyPanel4 ( wx.Panel ):

	def __init__( self, parent,data, id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.Size( 500,320 ), style = wx.TAB_TRAVERSAL, name = wx.EmptyString ):
		wx.Panel.__init__ ( self, parent, id = id, pos = pos, size = size, style = style, name = name )

		Vsz1 = wx.BoxSizer( wx.VERTICAL )

		#self.data = [False,True,True,True,True,True]
		self.data = []
		for d in data[0]:
			if d == 'T':
				self.data.append(True)
			if d == 'F':
				self.data.append(False)
		#self.data = data
		D = data[1].split(';')
		#print(D)
		r = int(D[0]);c = int(D[1]); auipos = int(D[2]); auirow = int(D[3])
		posis = wx.Position(r,c)
		#print(data[1],r,c,auipos,auirow)

		self.Items = [(u'dock_fixed',self.data[0]),(u'floatable',self.data[1]),(u'bottom Dockable',self.data[2]),
		              (u'Top Dockable',self.data[3]),(u'Left Dockable',self.data[4]),(u'Right Dockable',self.data[5])]

		self.PGrid1 = pg.PropertyGrid(self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.propgrid.PG_DEFAULT_STYLE|wx.propgrid.PG_SPLITTER_AUTO_CENTER|wx.propgrid.PG_TOOLTIPS)
		self.Item1 = self.PGrid1.Append( pg.PropertyCategory( u"Docking", u"Docking" ) )

		for itm in self.Items:
			self.PGrid1.Append( pg.BoolProperty(itm[0], itm[0], value=itm[1] ) )
			self.PGrid1.SetPropertyAttribute(itm[0], "UseCheckbox", True)


		self.Item3 = self.PGrid1.Append( PosProperty( u"pane_position", u"pane_position", value=posis ) )
		self.Item4 = self.PGrid1.Append( pg.IntProperty( u"aui_position", u"aui_position" ,value=auipos) )
		self.Item5 = self.PGrid1.Append( pg.IntProperty( u"aui_row", u"aui_row" ,value=auirow) )

		Vsz1.Add( self.PGrid1, 1, wx.ALL|wx.EXPAND, 5 )

		Hsz1 = wx.BoxSizer( wx.HORIZONTAL )

		self.btn1 = wx.Button( self, wx.ID_ANY, _(u"Cancel"), wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz1.Add( self.btn1, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.btn2 = wx.Button( self, wx.ID_ANY, _(u"Ok"), wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz1.Add( self.btn2, 0, wx.ALL, 5 )


		Vsz1.Add( Hsz1, 0, wx.ALIGN_CENTER_HORIZONTAL, 5 )


		self.SetSizer( Vsz1 )
		self.Layout()

		# Connect Events
		self.btn1.Bind( wx.EVT_BUTTON, self.cncl )
		self.btn2.Bind( wx.EVT_BUTTON, self.okit )

	def __del__( self ):
		pass


	# Virtual event handlers, overide them in your derived class
	def cncl( self, event ):
		q = self.GetParent()
		q.Close()

	def okit( self, event ):
		self.e = self.PGrid1.GetPropertyValues()
		#print(self.e)
		q = self.GetParent()
		q.Close()





# In the name of God
# -*- coding: utf-8 -*-
# Windows and Panels main Frame File
# ! /usr/bin/env python

import wx


class MyPanel1(wx.Panel):
	def __init__(self, parent, id, pos, size, style):
		wx.Panel.__init__(self, parent, id=wx.ID_ANY, pos=wx.DefaultPosition, size=wx.Size(-1, -1),
		                  style=wx.TAB_TRAVERSAL)

		self.parent = parent


		VSiz = wx.BoxSizer(wx.VERTICAL)
		# You must write your source here




		self.SetSizer(VSiz)
		self.Layout()


# -*- coding: utf-8 -*-

###########################################################################
## Python code generated with wxFormBuilder (version Oct 26 2018)
## http://www.wxformbuilder.org/
##
## Please DO NOT Change Panel name (P19)
###########################################################################

import wx
import wx.xrc

import os

import Src.MLA.NeruNet as NN
from scipy.io import loadmat
import numpy as np

###########################################################################
## Class P19 Temp Panel
###########################################################################

class P19 ( wx.Panel ):

	def __init__( self, parent, id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.Size( 250,250 ), style = wx.BORDER_RAISED|wx.TAB_TRAVERSAL, name = wx.EmptyString ):
		wx.Panel.__init__ ( self, parent, id = id, pos = pos, size = size, style = style, name = name )

		Vsp19 = wx.BoxSizer( wx.VERTICAL )

		Hsz1 = wx.BoxSizer( wx.HORIZONTAL )
		#you can add object in this BoxSizer
		self.lblm = wx.StaticText(self, wx.ID_ANY, u"m =  ", wx.DefaultPosition, wx.DefaultSize, 0)
		self.lblm.Wrap(-1)

		Hsz1.Add(self.lblm, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		self.Sc1 = wx.SpinCtrl(self, wx.ID_ANY, u"m", wx.DefaultPosition, wx.Size(60, -1), wx.SP_ARROW_KEYS, 0, 9999,
		                       0)
		Hsz1.Add(self.Sc1, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)


		Vsp19.Add( Hsz1, 0, wx.EXPAND, 5 )

		Hsz2 = wx.BoxSizer( wx.HORIZONTAL )
		# you can add object in this BoxSizer


		Vsp19.Add( Hsz2, 0, wx.EXPAND, 5 )

		Hsz3 = wx.BoxSizer( wx.HORIZONTAL )
		# you can add object in this BoxSizer


		Vsp19.Add( Hsz3, 0, wx.EXPAND, 5 )

		Hsz4 = wx.BoxSizer( wx.HORIZONTAL )
		# you can add object in this BoxSizer


		Vsp19.Add( Hsz4, 0, wx.EXPAND, 5 )

		Hsz5 = wx.BoxSizer( wx.HORIZONTAL )
		# you can add object in this BoxSizer

		Vsp19.Add( Hsz5, 0, wx.EXPAND, 5 )


		self.SetSizer( Vsp19 )
		self.Layout()

		# Connect Events
		self.Bind( wx.EVT_INIT_DIALOG, self.Start )

	def __del__( self ):
		pass


	# Virtual event handlers, overide them in your derived class
	def Start( self ):
		dlg = wx.FileDialog(self, message="Choose Database",
		                    defaultDir=os.getcwd(),defaultFile="",
		                    wildcard="All file(*.*)|*.*",
		                    style=wx.FD_OPEN | wx.FD_CHANGE_DIR)
		if dlg.ShowModal() == wx.ID_OK:
			paths = dlg.GetPaths()
		#print(paths)
		dlg.Destroy()
		data = loadmat(paths[0])
		#print(data)
		X = data['X']
		y = data['y'].flatten()
		sel = np.random.permutation(X)[:100]
		NN.display_data(sel)
		m = X.shape[0]
		print(m)

	def Test( self ):
		print('work it')




# -*- coding: utf-8 -*-

###########################################################################
## Python code generated with wxFormBuilder (version Oct 26 2018)
## http://www.wxformbuilder.org/
##
## You Can Edit This File : This is wrong >>> PLEASE DO *NOT* EDIT THIS FILE!
###########################################################################

import wx

###########################################################################
## Class MyPanel1
###########################################################################

class MyPanel1 ( wx.Panel ):

	def __init__( self, parent, id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.Size( 500,300 ), style = wx.TAB_TRAVERSAL, name = wx.EmptyString ):
		wx.Panel.__init__ ( self, parent, id = id, pos = pos, size = size, style = style, name = name )

		bSizer1 = wx.BoxSizer( wx.VERTICAL )

		self.Text1 = wx.StaticText( self, wx.ID_ANY, u"This is a Demo Frame", wx.DefaultPosition, wx.DefaultSize, wx.ALIGN_CENTER_HORIZONTAL )
		self.Text1.Wrap( -1 )

		self.Text1.SetFont( wx.Font( 45, wx.FONTFAMILY_DEFAULT, wx.FONTSTYLE_NORMAL, wx.FONTWEIGHT_NORMAL, False, wx.EmptyString ) )

		bSizer1.Add( self.Text1, 1, wx.ALIGN_CENTER_HORIZONTAL|wx.ALL, 5 )

		self.button1 = wx.Button( self, wx.ID_ANY, u"Okey", wx.DefaultPosition, wx.DefaultSize, 0 )
		bSizer1.Add( self.button1, 0, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL, 5 )


		self.SetSizer( bSizer1 )
		self.Layout()

		# Connect Events
		self.button1.Bind( wx.EVT_BUTTON, self.retrn )

	def __del__( self ):
		pass


	# Virtual event handlers, overide them in your derived class
	def retrn( self, event ):
		q = self.GetParent()
		q.Close()


